.. include:: ../../README.rst

Configuration
-------------

.. literalinclude:: ../../config/cmkinitramfs.ini.example
   :language: ini
   :linenos:


Table of contents
=================

.. toctree::
   :maxdepth: 2
   :numbered:

   init
   data
   initramfs
   item
   bin
   entry
   utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

